@@ -17,13 +17,15 @@
  *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
  */
 
-#ifndef ALTERNATIVESDIALOG_H
-#define ALTERNATIVESDIALOG_H
-
-#include <Plasma/Applet>
+#ifndef ALTERNATIVESHELPER_H
+#define ALTERNATIVESHELPER_H
 
+// Qt
 #include <QQuickItem>
 
+// Plasma
+#include <Plasma/Applet>
+
 class AlternativesHelper : public QObject
 {
     Q_OBJECT
