@@ -20,6 +20,7 @@
 #ifndef SCREENPOOL_H
 #define SCREENPOOL_H
 
+// Qt
 #include <QObject>
 #include <QHash>
 #include <QScreen>
@@ -27,6 +28,7 @@
 #include <QTimer>
 #include <QAbstractNativeEventFilter>
 
+// KDE
 #include <KConfigGroup>
 #include <KSharedConfig>
 
@@ -41,7 +43,8 @@ public:
     void load();
     ~ScreenPool() override;
 
-    bool screenExists(int id);
+    bool hasId(int id) const;
+    bool screenExists(int id) const;
     int primaryScreenId() const;
 
     QString primaryConnector() const;
@@ -56,6 +59,8 @@ public:
 
     int firstAvailableId() const;
 
+    QString reportHtml(const QList<int> &assignedScreens) const;
+
     //all ids that are known, included screens not enabled at the moment
     QList <int> knownIds() const;
 
