@@ -110,6 +110,8 @@ private:
     QList<QMetaObject::Connection> connections;
 
     Plasma::FrameSvg::EnabledBorders m_enabledBorders{Plasma::FrameSvg::AllBorders};
+    //only for the mask on disabled compositing, not to actually paint
+    Plasma::FrameSvg *m_background{nullptr};
 
     Latte::Corona *m_corona{nullptr};
     Latte::WindowSystem::WindowId m_waylandWindowId;
