@@ -20,8 +20,10 @@
 #ifndef MENU_H
 #define MENU_H
 
+// Qt
 #include <QObject>
 
+// Plasma
 #include <Plasma/ContainmentActions>
 
 class QAction;
@@ -46,7 +48,7 @@ private Q_SLOTS:
 
 
 private:
-    QStringList m_layoutsData;
+    QStringList m_data;
 
     QList<QAction *>m_actions;
 
